summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
authorGabor Greif <ggreif@gmail.com>2007-07-05 17:07:56 +0000
committerGabor Greif <ggreif@gmail.com>2007-07-05 17:07:56 +0000
commita99be51bf5cdac1438069d4b01766c47704961c8 (patch)
treec743819ee5ce71fc3aa76ed445ca89201b4daf4a /tools
parentf8ad9552215503f7573b5049567ed59c37cc9636 (diff)
downloadllvm-a99be51bf5cdac1438069d4b01766c47704961c8.tar.gz
llvm-a99be51bf5cdac1438069d4b01766c47704961c8.tar.bz2
llvm-a99be51bf5cdac1438069d4b01766c47704961c8.tar.xz
Here is the bulk of the sanitizing.
Almost all occurrences of "bytecode" in the sources have been eliminated. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@37913 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'tools')
-rw-r--r--tools/llc/llc.cpp6
-rw-r--r--tools/lli/lli.cpp4
-rw-r--r--tools/llvm-ar/llvm-ar.cpp14
-rw-r--r--tools/llvm-as/llvm-as.cpp2
-rw-r--r--tools/llvm-db/Commands.cpp2
-rw-r--r--tools/llvm-dis/llvm-dis.cpp8
-rw-r--r--tools/llvm-extract/llvm-extract.cpp4
-rw-r--r--tools/llvm-ld/llvm-ld.cpp66
-rw-r--r--tools/llvm-link/llvm-link.cpp10
-rw-r--r--tools/llvm-nm/llvm-nm.cpp4
-rw-r--r--tools/llvm-prof/llvm-prof.cpp10
-rw-r--r--tools/llvm-ranlib/llvm-ranlib.cpp2
-rw-r--r--tools/llvm2cpp/llvm2cpp.cpp4
-rw-r--r--tools/llvmc/CompilerDriver.cpp22
-rw-r--r--tools/llvmc/CompilerDriver.h6
-rw-r--r--tools/llvmc/ConfigLexer.h2
-rw-r--r--tools/llvmc/ConfigLexer.l6
-rw-r--r--tools/llvmc/Configuration.cpp10
-rw-r--r--tools/llvmc/llvmc.cpp2
-rw-r--r--tools/lto/lto-c.cpp2
-rw-r--r--tools/lto/lto.cpp6
-rw-r--r--tools/opt/opt.cpp10
22 files changed, 101 insertions, 101 deletions
diff --git a/tools/llvm-as/llvm-as.cpp b/tools/llvm-as/llvm-as.cpp
index e4c7344776..41b6846fe1 100644
--- a/tools/llvm-as/llvm-as.cpp
+++ b/tools/llvm-as/llvm-as.cpp
@@ -125,7 +125,7 @@ int main(int argc, char **argv) {
return 1;
}
- if (Force || !CheckBytecodeOutputToConsole(Out,true))
+ if (Force || !CheckBitcodeOutputToConsole(Out,true))
WriteBitcodeToFile(M.get(), *Out);
} catch (const std::string& msg) {
cerr << argv[0] << ": " << msg << "\n";
diff --git a/tools/llvm-db/Commands.cpp b/tools/llvm-db/Commands.cpp
index e0162e3956..a3d14b0085 100644
--- a/tools/llvm-db/Commands.cpp
+++ b/tools/llvm-db/Commands.cpp
@@ -219,7 +219,7 @@ void CLIDebugger::parseProgramOptions(std::string &Options) {
/// file command - If the user specifies an option, search the PATH for the
-/// specified program/bytecode file and load it. If the user does not specify
+/// specified program/bitcode file and load it. If the user does not specify
/// an option, unload the current program.
void CLIDebugger::fileCommand(std::string &Options) {
std::string Prog = getToken(Options);
diff --git a/tools/llvm-extract/llvm-extract.cpp b/tools/llvm-extract/llvm-extract.cpp
index 441063848c..becceb690b 100644
--- a/tools/llvm-extract/llvm-extract.cpp
+++ b/tools/llvm-extract/llvm-extract.cpp
@@ -28,7 +28,7 @@ using namespace llvm;
// InputFilename - The filename to read from.
static cl::opt<std::string>
-InputFilename(cl::Positional, cl::desc("<input bytecode file>"),
+InputFilename(cl::Positional, cl::desc("<input bitcode file>"),
cl::init("-"), cl::value_desc("filename"));
static cl::opt<std::string>
@@ -67,7 +67,7 @@ int main(int argc, char **argv) {
delete Buffer;
if (M.get() == 0) {
- cerr << argv[0] << ": bytecode didn't read correctly.\n";
+ cerr << argv[0] << ": bitcode didn't read correctly.\n";
return 1;
}
diff --git a/tools/llvm-ranlib/llvm-ranlib.cpp b/tools/llvm-ranlib/llvm-ranlib.cpp
index 440b536194..9085b7ed45 100644
--- a/tools/llvm-ranlib/llvm-ranlib.cpp
+++ b/tools/llvm-ranlib/llvm-ranlib.cpp
@@ -48,7 +48,7 @@ int main(int argc, char **argv) {
// like --help and --version.
cl::ParseCommandLineOptions(argc, argv,
" LLVM Archive Index Generator (llvm-ranlib)\n\n"
- " This program adds or updates an index of bytecode symbols\n"
+ " This program adds or updates an index of bitcode symbols\n"
" to an LLVM archive file."
);
diff --git a/tools/llvm2cpp/llvm2cpp.cpp b/tools/llvm2cpp/llvm2cpp.cpp
index d4382cd5ce..2db7543f48 100644
--- a/tools/llvm2cpp/llvm2cpp.cpp
+++ b/tools/llvm2cpp/llvm2cpp.cpp
@@ -31,7 +31,7 @@
using namespace llvm;
static cl::opt<std::string>
-InputFilename(cl::Positional, cl::desc("<input LLVM bytecode file>"),
+InputFilename(cl::Positional, cl::desc("<input LLVM bitcode file>"),
cl::init("-"));
static cl::opt<std::string>
@@ -60,7 +60,7 @@ int main(int argc, char **argv) {
if (ErrorMessage.size())
std::cerr << ErrorMessage << "\n";
else
- std::cerr << "bytecode didn't read correctly.\n";
+ std::cerr << "bitcode didn't read correctly.\n";
return 1;
}
diff --git a/tools/llvmc/CompilerDriver.h b/tools/llvmc/CompilerDriver.h
index 02ec0e9f52..f2be5cc8cf 100644
--- a/tools/llvmc/CompilerDriver.h
+++ b/tools/llvmc/CompilerDriver.h
@@ -43,10 +43,10 @@ namespace llvm {
/// @brief The phases of processing that llvmc understands
enum Phases {
PREPROCESSING, ///< Source language combining, filtering, substitution
- TRANSLATION, ///< Translate source -> LLVM bytecode/assembly
+ TRANSLATION, ///< Translate source -> LLVM bitcode/assembly
OPTIMIZATION, ///< Optimize translation result
ASSEMBLY, ///< Convert program to executable
- LINKING, ///< Link bytecode and native code
+ LINKING, ///< Link bitcode and native code
NUM_PHASES ///< Always last!
};
@@ -129,7 +129,7 @@ namespace llvm {
TIME_ACTIONS_FLAG = 0x0010, ///< Time the actions as they execute
SHOW_STATS_FLAG = 0x0020, ///< Show pass statistics
EMIT_NATIVE_FLAG = 0x0040, ///< Emit native code instead of bc
- EMIT_RAW_FLAG = 0x0080, ///< Emit raw, unoptimized bytecode
+ EMIT_RAW_FLAG = 0x0080, ///< Emit raw, unoptimized bitcode
KEEP_TEMPS_FLAG = 0x0100, ///< Don't delete temporary files
STRIP_OUTPUT_FLAG = 0x0200, ///< Strip symbols from linked output
DRIVER_FLAGS_MASK = 0x03FF ///< Union of the above flags
diff --git a/tools/llvmc/ConfigLexer.h b/tools/llvmc/ConfigLexer.h
index 39960c88b9..9693b34bb4 100644
--- a/tools/llvmc/ConfigLexer.h
+++ b/tools/llvmc/ConfigLexer.h
@@ -56,7 +56,7 @@ enum ConfigLexerTokens {
BINDIR_SUBST, ///< The substitution item %bindir%
ASSEMBLY, ///< The value "assembly" (and variants)
ASSEMBLER, ///< The name "assembler" (and variants)
- BYTECODE, ///< The value "bytecode" (and variants)
+ BITCODE, ///< The value "bitcode" (and variants)
COMMAND, ///< The name "command" (and variants)
DEFS_SUBST, ///< The substitution item %defs%
EQUALS, ///< The equals sign, =
diff --git a/tools/llvmc/ConfigLexer.l b/tools/llvmc/ConfigLexer.l
index 34b9a17de1..6bd61c85b9 100644
--- a/tools/llvmc/ConfigLexer.l
+++ b/tools/llvmc/ConfigLexer.l
@@ -79,7 +79,7 @@ ASSEMBLER assembler|Assembler|ASSEMBLER
COMMAND command|Command|COMMAND
LANG lang|Lang|LANG
LIBS libs|Libs|LIBS
-LINKER linker|Linker|LINKER
+LINKER linker|Linker|LINKER
NAME name|Name|NAME
OPT1 opt1|Opt1|OPT1
OPT2 opt2|Opt2|OPT2
@@ -97,7 +97,7 @@ VERSION version|Version|VERSION
True true|True|TRUE|on|On|ON|yes|Yes|YES
False false|False|FALSE|off|Off|OFF|no|No|NO
-Bytecode bc|BC|bytecode|Bytecode|BYTECODE
+Bitcode bc|BC|bitcode|Bitcode|BITCODE
Assembly asm|ASM|assembly|Assembly|ASSEMBLY
BadSubst \%[a-zA-Z]*\%
@@ -186,7 +186,7 @@ White [ \t]*
%WOpts% { return handleSubstitution(WOPTS_SUBST); }
{Assembly} { return handleValueContext(ASSEMBLY); }
-{Bytecode} { return handleValueContext(BYTECODE); }
+{Bitcode} { return handleValueContext(BITCODE); }
{True} { return handleValueContext(TRUETOK); }
{False} { return handleValueContext(FALSETOK); }
diff --git a/tools/llvmc/Configuration.cpp b/tools/llvmc/Configuration.cpp
index 1364e9b2eb..aafca792b1 100644
--- a/tools/llvmc/Configuration.cpp
+++ b/tools/llvmc/Configuration.cpp
@@ -291,8 +291,8 @@ namespace {
case ASSEMBLY:
str += "assembly";
break;
- case BYTECODE:
- str += "bytecode";
+ case BITCODE:
+ str += "bitcode";
break;
case TRUETOK:
str += "true";
@@ -340,8 +340,8 @@ namespace {
case ASSEMBLY:
anOption += "assembly";
break;
- case BYTECODE:
- anOption += "bytecode";
+ case BITCODE:
+ anOption += "bitcode";
break;
case TRUETOK:
anOption += "true";
@@ -392,7 +392,7 @@ namespace {
next();
if (token == ASSEMBLY) {
return true;
- } else if (token == BYTECODE) {
+ } else if (token == BITCODE) {
return false;
} else {
error("Expecting output type value");
diff --git a/tools/llvmc/llvmc.cpp b/tools/llvmc/llvmc.cpp
index 081ae453ec..c257a3ebab 100644
--- a/tools/llvmc/llvmc.cpp
+++ b/tools/llvmc/llvmc.cpp
@@ -143,7 +143,7 @@ static cl::opt<std::string> OutputMachine("m", cl::Prefix,
cl::desc("Specify a target machine"), cl::value_desc("machine"));
static cl::opt<bool> Native("native", cl::init(false),
- cl::desc("Generative native code instead of bytecode"));
+ cl::desc("Generative native code instead of bitcode"));
static cl::opt<bool> DebugOutput("g", cl::init(false),
cl::desc("Generate objects that include debug symbols"));
diff --git a/tools/lto/lto-c.cpp b/tools/lto/lto-c.cpp
index f89b374e19..ae939a99bf 100644
--- a/tools/lto/lto-c.cpp
+++ b/tools/lto/lto-c.cpp
@@ -30,7 +30,7 @@ void llvm_destroy_optimizer(llvm_lto_t lto) {
delete (llvm::LTO*)lto;
}
-/// Read an LLVM bytecode file using LTO::readLLVMObjectFile.
+/// Read an LLVM bitcode file using LTO::readLLVMObjectFile.
extern "C"
llvm_lto_status
llvm_read_object_file(llvm_lto_t lto, const char *input_filename) {
diff --git a/tools/lto/lto.cpp b/tools/lto/lto.cpp
index 3420cdf67b..dacea661d1 100644
--- a/tools/lto/lto.cpp
+++ b/tools/lto/lto.cpp
@@ -107,7 +107,7 @@ LTO::removeModule (const std::string &InputFilename)
delete m;
}
-/// InputFilename is a LLVM bytecode file. If Module with InputFilename is
+/// InputFilename is a LLVM bitcode file. If Module with InputFilename is
/// available then return it. Otherwise parseInputFilename.
Module *
LTO::getModule(const std::string &InputFilename)
@@ -128,7 +128,7 @@ LTO::getModule(const std::string &InputFilename)
return m;
}
-/// InputFilename is a LLVM bytecode file. Reade this bytecode file and
+/// InputFilename is a LLVM bitcode file. Reade this bitcode file and
/// set corresponding target triplet string.
void
LTO::getTargetTriple(const std::string &InputFilename,
@@ -139,7 +139,7 @@ LTO::getTargetTriple(const std::string &InputFilename,
targetTriple = m->getTargetTriple();
}
-/// InputFilename is a LLVM bytecode file. Read it using bytecode reader.
+/// InputFilename is a LLVM bitcode file. Read it using bitcode reader.
/// Collect global functions and symbol names in symbols vector.
/// Collect external references in references vector.
/// Return LTO_READ_SUCCESS if there is no error.
diff --git a/tools/llc/llc.cpp b/tools/llc/llc.cpp
index 8797c58ce8..b53f59b41c 100644
--- a/tools/llc/llc.cpp
+++ b/tools/llc/llc.cpp
@@ -9,7 +9,7 @@
//
// This is the llc code generator driver. It provides a convenient
// command-line interface for generating native assembly-language code
// or C code, given LLVM bytecode.
//
//===----------------------------------------------------------------------===//
@@ -44,7 +44,7 @@ using namespace llvm;
// and back-end code generation options are specified with the target machine.
//
static cl::opt<std::string>
-InputFilename(cl::Positional, cl::desc("<input bytecode>"), cl::init("-"));
+InputFilename(cl::Positional, cl::desc("<input bitcode>"), cl::init("-"));
static cl::opt<std::string>
OutputFilename("o", cl::desc("Output filename"), cl::value_desc("filename"));
@@ -184,7 +184,7 @@ int main(int argc, char **argv) {
if (Buffer.get())
M.reset(ParseBitcodeFile(Buffer.get(), &ErrorMessage));
if (M.get() == 0) {
- std::cerr << argv[0] << ": bytecode didn't read correctly.\n";
+ std::cerr << argv[0] << ": bitcode didn't read correctly.\n";
std::cerr << "Reason: " << ErrorMessage << "\n";
return 1;
}
@@ -9,7 +9,7 @@
// This is the llc code generator driver. It provides a convenient
// command-line interface for generating native assembly-language code
-// or C code, given LLVM bytecode.
+// or C code, given LLVM bitcode.
//
//===----------------------------------------------------------------------===//
diff --git a/tools/lli/lli.cpp b/tools/lli/lli.cpp
index fdb5f4aa39..3ce28077ae 100644
--- a/tools/lli/lli.cpp
+++ b/tools/lli/lli.cpp
@@ -33,7 +33,7 @@ using namespace llvm;
namespace {
cl::opt<std::string>
- InputFile(cl::desc("<input bytecode>"), cl::Positional, cl::init("-"));
+ InputFile(cl::desc("<input bitcode>"), cl::Positional, cl::init("-"));
cl::list<std::string>
InputArgv(cl::ConsumeAfter, cl::desc("<program arguments>..."));
@@ -74,7 +74,7 @@ int main(int argc, char **argv, char * const *envp) {
if (DisableCoreFiles)
sys::Process::PreventCoreFiles();
// Load the bytecode...
std::string ErrorMsg;
ModuleProvider *MP = 0;
if (MemoryBuffer *Buffer = MemoryBuffer::getFileOrSTDIN(InputFile,&ErrorMsg)){
@@ -74,7 +74,7 @@ int main(int argc, char **argv, char * const *envp) {
if (DisableCoreFiles)
sys::Process::PreventCoreFiles();
- // Load the bytecode...
+ // Load the bitcode...
std::string ErrorMsg;
ModuleProvider *MP = 0;
diff --git a/tools/llvm-ar/llvm-ar.cpp b/tools/llvm-ar/llvm-ar.cpp
index d0601c66c1..2cd16e361e 100644
--- a/tools/llvm-ar/llvm-ar.cpp
+++ b/tools/llvm-ar/llvm-ar.cpp
@@ -8,7 +8,7 @@
//===----------------------------------------------------------------------===//
//
// Builds up (relatively) standard unix archive files (.a) containing LLVM
// bytecode or other files.
//
//===----------------------------------------------------------------------===//
@@ -54,7 +54,7 @@ static cl::extrahelp MoreHelp(
" [b] - put file(s) before [relpos] (same as [i])\n"
" [f] - truncate inserted file names\n"
" [i] - put file(s) before [relpos] (same as [b])\n"
- " [k] - always print bytecode files (default is to skip them)\n"
+ " [k] - always print bitcode files (default is to skip them)\n"
" [N] - use instance [count] of name\n"
" [o] - preserve original dates\n"
" [P] - use full path names when matching\n"
@@ -88,7 +88,7 @@ bool AddBefore = false; ///< 'b' modifier
bool Create = false; ///< 'c' modifier
bool TruncateNames = false; ///< 'f' modifier
bool InsertBefore = false; ///< 'i' modifier
-bool DontSkipBytecode = false; ///< 'k' modifier
+bool DontSkipBitcode = false; ///< 'k' modifier
bool UseCount = false; ///< 'N' modifier
bool OriginalDates = false; ///< 'o' modifier
bool FullPath = false; ///< 'P' modifier
@@ -193,7 +193,7 @@ ArchiveOperation parseCommandLine() {
case 'x': ++NumOperations; Operation = Extract; break;
case 'c': Create = true; break;
case 'f': TruncateNames = true; break;
- case 'k': DontSkipBytecode = true; break;
+ case 'k': DontSkipBitcode = true; break;
case 'l': /* accepted but unused */ break;
case 'o': OriginalDates = true; break;
case 'P': FullPath = true; break;
@@ -341,7 +341,7 @@ void printSymbolTable() {
// doPrint - Implements the 'p' operation. This function traverses the archive
// looking for members that match the path list. It is careful to uncompress
// things that should be and to skip bytecode files unless the 'k' modifier was
// given.
bool doPrint(std::string* ErrMsg) {
if (buildPaths(false, ErrMsg))
@@ -356,7 +356,7 @@ bool doPrint(std::string* ErrMsg) {
// Skip things that don't make sense to print
if (I->isLLVMSymbolTable() || I->isSVR4SymbolTable() ||
- I->isBSD4SymbolTable() || (!DontSkipBytecode &&
+ I->isBSD4SymbolTable() || (!DontSkipBitcode &&
(I->isBytecode() || I->isCompressedBytecode())))
continue;
@@ -694,7 +694,7 @@ int main(int argc, char **argv) {
// like --help and --version.
cl::ParseCommandLineOptions(argc, argv,
" LLVM Archiver (llvm-ar)\n\n"
- " This program archives bytecode files into single libraries\n"
+ " This program archives bitcode files into single libraries\n"
);
// Print a stack trace if we signal out.
@@ -8,7 +8,7 @@
//
// Builds up (relatively) standard unix archive files (.a) containing LLVM
-// bytecode or other files.
+// bitcode or other files.
//
//===----------------------------------------------------------------------===//
@@ -341,7 +341,7 @@ void printSymbolTable() {
// doPrint - Implements the 'p' operation. This function traverses the archive
// looking for members that match the path list. It is careful to uncompress
-// things that should be and to skip bytecode files unless the 'k' modifier was
+// things that should be and to skip bitcode files unless the 'k' modifier was
// given.
bool doPrint(std::string* ErrMsg) {
diff --git a/tools/llvm-dis/llvm-dis.cpp b/tools/llvm-dis/llvm-dis.cpp
index 97ec4c7306..0c87f8ce66 100644
--- a/tools/llvm-dis/llvm-dis.cpp
+++ b/tools/llvm-dis/llvm-dis.cpp
@@ -8,8 +8,8 @@
//===----------------------------------------------------------------------===//
//
// This utility may be invoked in the following manner:
// llvm-dis [options] - Read LLVM bytecode from stdin, write asm to stdout
// llvm-dis [options] x.bc - Read LLVM bytecode from the x.bc file, write asm
// to the x.ll file.
// Options:
// --help - Output information about command line switches
@@ -31,7 +31,7 @@
using namespace llvm;
static cl::opt<std::string>
-InputFilename(cl::Positional, cl::desc("<input bytecode>"), cl::init("-"));
+InputFilename(cl::Positional, cl::desc("<input bitcode>"), cl::init("-"));
static cl::opt<std::string>
OutputFilename("o", cl::desc("Override output filename"),
@@ -65,7 +65,7 @@ int main(int argc, char **argv) {
if (ErrorMessage.size())
cerr << ErrorMessage << "\n";
else
- cerr << "bytecode didn't read correctly.\n";
+ cerr << "bitcode didn't read correctly.\n";
return 1;
}
@@ -8,8 +8,8 @@
//
// This utility may be invoked in the following manner:
-// llvm-dis [options] - Read LLVM bytecode from stdin, write asm to stdout
-// llvm-dis [options] x.bc - Read LLVM bytecode from the x.bc file, write asm
+// llvm-dis [options] - Read LLVM bitcode from stdin, write asm to stdout
+// llvm-dis [options] x.bc - Read LLVM bitcode from the x.bc file, write asm
// to the x.ll file.
// Options:
diff --git a/tools/llvm-ld/llvm-ld.cpp b/tools/llvm-ld/llvm-ld.cpp
index c86341fda5..46788b1011 100644
--- a/tools/llvm-ld/llvm-ld.cpp
+++ b/tools/llvm-ld/llvm-ld.cpp
@@ -11,7 +11,7 @@
// system 'ld' conventions. As such, the default output file is ./a.out.
// Additionally, this program outputs a shell script that is used to invoke LLI
// to execute the program. In this manner, the generated executable (a.out for
-// example), is directly executable, whereas the bytecode file actually lives in
+// example), is directly executable, whereas the bitcode file actually lives in
// the a.out.bc file generated by this program. Also, Force is on by default.
//
// Note that if someone (or a script) deletes the executable program generated,
@@ -42,7 +42,7 @@ using namespace llvm;
// Input/Output Options
static cl::list<std::string> InputFilenames(cl::Positional, cl::OneOrMore,
- cl::desc("<input bytecode files>"));
+ cl::desc("<input bitcode files>"));
static cl::opt<std::string> OutputFilename("o", cl::init("a.out"),
cl::desc("Override output filename"),
@@ -203,11 +203,11 @@ static void RemoveEnv(const char * name, char ** const envp) {
return;
}
-/// GenerateBytecode - generates a bytecode file from the module provided
-void GenerateBytecode(Module* M, const std::string& FileName) {
+/// GenerateBitcode - generates a bitcode file from the module provided
+void GenerateBitcode(Module* M, const std::string& FileName) {
if (Verbose)
- cout << "Generating Bytecode To " << FileName << '\n';
+ cout << "Generating Bitcode To " << FileName << '\n';
// Create the output file.
std::ios::openmode io_mode = std::ios::out | std::ios::trunc |
@@ -216,22 +216,22 @@ void GenerateBytecode(Module* M, const std::string& FileName) {
if (!Out.good())
PrintAndExit("error opening '" + FileName + "' for writing!");
- // Ensure that the bytecode file gets removed from the disk if we get a
+ // Ensure that the bitcode file gets removed from the disk if we get a
// terminating signal.
sys::RemoveFileOnSignal(sys::Path(FileName));
// Write it out
WriteBitcodeToFile(M, Out);
- // Close the bytecode file.
+ // Close the bitcode file.
Out.close();
}
/// GenerateAssembly - generates a native assembly language source file from the
-/// specified bytecode file.
+/// specified bitcode file.
///
/// Inputs:
-/// InputFilename - The name of the input bytecode file.
+/// InputFilename - The name of the input bitcode file.
/// OutputFilename - The name of the file to generate.
/// llc - The pathname to use for LLC.
/// envp - The environment to use when running LLC.
@@ -242,7 +242,7 @@ static int GenerateAssembly(const std::string &OutputFilename,
const std::string &InputFilename,
const sys::Path &llc,
std::string &ErrMsg ) {
- // Run LLC to convert the bytecode file into assembly code.
+ // Run LLC to convert the bitcode file into assembly code.
std::vector<const char*> args;
args.push_back(llc.c_str());
args.push_back("-f");
@@ -259,12 +259,12 @@ static int GenerateAssembly(const std::string &OutputFilename,
return sys::Program::ExecuteAndWait(llc, &args[0], 0, 0, 0, 0, &ErrMsg);
}
-/// GenerateCFile - generates a C source file from the specified bytecode file.
+/// GenerateCFile - generates a C source file from the specified bitcode file.
static int GenerateCFile(const std::string &OutputFile,
const std::string &InputFile,
const sys::Path &llc,
std::string& ErrMsg) {
- // Run LLC to convert the bytecode file into C.
+ // Run LLC to convert the bitcode file into C.
std::vector<const char*> args;
args.push_back(llc.c_str());
args.push_back("-march=c");
@@ -283,10 +283,10 @@ static int GenerateCFile(const std::string &OutputFile,
}
/// GenerateNative - generates a native object file from the
-/// specified bytecode file.
+/// specified bitcode file.
///
/// Inputs:
-/// InputFilename - The name of the input bytecode file.
+/// InputFilename - The name of the input bitcode file.
/// OutputFilename - The name of the file to generate.
/// NativeLinkItems - The native libraries, files, code with which to link
/// LibPaths - The list of directories in which to find libraries.
@@ -377,7 +377,7 @@ static int GenerateNative(const std::string &OutputFilename,
}
/// EmitShellScript - Output the wrapper file that invokes the JIT on the LLVM
-/// bytecode file for the program.
+/// bitcode file for the program.
static void EmitShellScript(char **argv) {
if (Verbose)
cout << "Emitting Shell Script\n";
@@ -478,7 +478,7 @@ int main(int argc, char **argv, char **envp) {
// Construct a Linker (now that Verbose is set)
Linker TheLinker(progname, OutputFilename, Verbose);
- // Keep track of the native link items (versus the bytecode items)
+ // Keep track of the native link items (versus the bitcode items)
Linker::ItemList NativeLinkItems;
// Add library paths to the linker
@@ -517,10 +517,10 @@ int main(int argc, char **argv, char **envp) {
// Optimize the module
Optimize(Composite.get());
- // Generate the bytecode for the optimized module.
- std::string RealBytecodeOutput = OutputFilename;
- if (!LinkAsLibrary) RealBytecodeOutput += ".bc";
- GenerateBytecode(Composite.get(), RealBytecodeOutput);
+ // Generate the bitcode for the optimized module.
+ std::string RealBitcodeOutput = OutputFilename;
+ if (!LinkAsLibrary) RealBitcodeOutput += ".bc";
+ GenerateBitcode(Composite.get(), RealBitcodeOutput);
// If we are not linking a library, generate either a native executable
// or a JIT shell script, depending upon what the user wants.
@@ -545,17 +545,17 @@ int main(int argc, char **argv, char **envp) {
const char* args[4];
args[0] = I->c_str();
- args[1] = RealBytecodeOutput.c_str();
+ args[1] = RealBitcodeOutput.c_str();
args[2] = tmp_output.c_str();
args[3] = 0;
if (0 == sys::Program::ExecuteAndWait(prog, args, 0,0,0,0, &ErrMsg)) {
- if (tmp_output.isBytecodeFile() || tmp_output.isBitcodeFile()) {
- sys::Path target(RealBytecodeOutput);
+ if (tmp_output.isBitcodeFile() || tmp_output.isBitcodeFile()) {
+ sys::Path target(RealBitcodeOutput);
target.eraseFromDisk();
if (tmp_output.renamePathOnDisk(target, &ErrMsg))
PrintAndExit(ErrMsg, 2);
} else
- PrintAndExit("Post-link optimization output is not bytecode");
+ PrintAndExit("Post-link optimization output is not bitcode");
} else {
PrintAndExit(ErrMsg);
}
@@ -563,9 +563,9 @@ int main(int argc, char **argv, char **envp) {
}
// If the user wants to generate a native executable, compile it from the
- // bytecode file.
+ // bitcode file.
//
- // Otherwise, create a script that will run the bytecode through the JIT.
+ // Otherwise, create a script that will run the bitcode through the JIT.
if (Native) {
// Name of the Assembly Language output file
sys::Path AssemblyFile ( OutputFilename);
@@ -584,9 +584,9 @@ int main(int argc, char **argv, char **envp) {
if (gcc.isEmpty())
PrintAndExit("Failed to find gcc");
- // Generate an assembly language file for the bytecode.
+ // Generate an assembly language file for the bitcode.
std::string ErrMsg;
- if (0 != GenerateAssembly(AssemblyFile.toString(), RealBytecodeOutput,
+ if (0 != GenerateAssembly(AssemblyFile.toString(), RealBitcodeOutput,
llc, ErrMsg))
PrintAndExit(ErrMsg);
@@ -613,10 +613,10 @@ int main(int argc, char **argv, char **envp) {
if (gcc.isEmpty())
PrintAndExit("Failed to find gcc");
- // Generate an assembly language file for the bytecode.
+ // Generate an assembly language file for the bitcode.
std::string ErrMsg;
if (0 != GenerateCFile(
- CFile.toString(), RealBytecodeOutput, llc, ErrMsg))
+ CFile.toString(), RealBitcodeOutput, llc, ErrMsg))
PrintAndExit(ErrMsg);
if (0 != GenerateNative(OutputFilename, CFile.toString(),
@@ -635,11 +635,11 @@ int main(int argc, char **argv, char **envp) {
if (sys::Path(OutputFilename).makeExecutableOnDisk(&ErrMsg))
PrintAndExit(ErrMsg);
- // Make the bytecode file readable and directly executable in LLEE as well
- if (sys::Path(RealBytecodeOutput).makeExecutableOnDisk(&ErrMsg))
+ // Make the bitcode file readable and directly executable in LLEE as well
+ if (sys::Path(RealBitcodeOutput).makeExecutableOnDisk(&ErrMsg))
PrintAndExit(ErrMsg);
- if (sys::Path(RealBytecodeOutput).makeReadableOnDisk(&ErrMsg))
+ if (sys::Path(RealBitcodeOutput).makeReadableOnDisk(&ErrMsg))
PrintAndExit(ErrMsg);
}
} catch (const std::string& msg) {
diff --git a/tools/llvm-link/llvm-link.cpp b/tools/llvm-link/llvm-link.cpp
index 28be3a97f3..5db13aabae 100644
--- a/tools/llvm-link/llvm-link.cpp
+++ b/tools/llvm-link/llvm-link.cpp
@@ -28,7 +28,7 @@ using namespace llvm;
static cl::list<std::string>
InputFilenames(cl::Positional, cl::OneOrMore,
- cl::desc("<input bytecode files>"));
+ cl::desc("<input bitcode files>"));
static cl::opt<std::string>
OutputFilename("o", cl::desc("Override output filename"), cl::init("-"),
@@ -42,7 +42,7 @@ Verbose("v", cl::desc("Print information about actions taken"));
static cl::opt<bool>
DumpAsm("d", cl::desc("Print assembly as linked"), cl::Hidden);
// LoadFile - Read the specified bytecode file in and return it. This routine
// searches the link path for the specified file to try to find it...
//
static inline std::auto_ptr<Module> LoadFile(const std::string &FN) {
@@ -66,12 +66,12 @@ static inline std::auto_ptr<Module> LoadFile(const std::string &FN) {
if (Result) return std::auto_ptr<Module>(Result); // Load successful!
if (Verbose) {
- cerr << "Error opening bytecode file: '" << Filename.c_str() << "'";
+ cerr << "Error opening bitcode file: '" << Filename.c_str() << "'";
if (ErrorMessage.size()) cerr << ": " << ErrorMessage;
cerr << "\n";
}
} else {
- cerr << "Bytecode file: '" << Filename.c_str() << "' does not exist.\n";
+ cerr << "Bitcode file: '" << Filename.c_str() << "' does not exist.\n";
}
return std::auto_ptr<Module>();
@@ -142,7 +142,7 @@ int main(int argc, char **argv) {
return 1;
}
- if (Verbose) cerr << "Writing bytecode...\n";
+ if (Verbose) cerr << "Writing bitcode...\n";
WriteBitcodeToFile(Composite.get(), *Out);
if (Out != &std::cout) delete Out;
@@ -42,7 +42,7 @@ Verbose("v", cl::desc("Print information about actions taken"));
static cl::opt<bool>
DumpAsm("d", cl::desc("Print assembly as linked"), cl::Hidden);
-// LoadFile - Read the specified bytecode file in and return it. This routine
+// LoadFile - Read the specified bitcode file in and return it. This routine
// searches the link path for the specified file to try to find it...
//
diff --git a/tools/llvm-nm/llvm-nm.cpp b/tools/llvm-nm/llvm-nm.cpp
index a1890a9d26..bf98653179 100644
--- a/tools/llvm-nm/llvm-nm.cpp
+++ b/tools/llvm-nm/llvm-nm.cpp
@@ -8,7 +8,7 @@
//===----------------------------------------------------------------------===//
//
// This program is a utility that works like traditional Unix "nm",
// that is, it prints out the names of symbols in a bytecode file,
// along with some information about each symbol.
//
// This "nm" does not print symbols' addresses. It supports many of
@@ -43,7 +43,7 @@ namespace {
cl::aliasopt(OutputFormat));
cl::list<std::string>
- InputFilenames(cl::Positional, cl::desc("<input bytecode files>"),
+ InputFilenames(cl::Positional, cl::desc("<input bitcode files>"),
cl::ZeroOrMore);
cl::opt<bool> UndefinedOnly("undefined-only",
@@ -8,7 +8,7 @@
//
// This program is a utility that works like traditional Unix "nm",
-// that is, it prints out the names of symbols in a bytecode file,
+// that is, it prints out the names of symbols in a bitcode file,
// along with some information about each symbol.
//
diff --git a/tools/llvm-prof/llvm-prof.cpp b/tools/llvm-prof/llvm-prof.cpp
index c85b0da1bc..dcb9d1ff21 100644
--- a/tools/llvm-prof/llvm-prof.cpp
+++ b/tools/llvm-prof/llvm-prof.cpp
@@ -32,8 +32,8 @@ using namespace llvm;
namespace {
cl::opt<std::string>
- BytecodeFile(cl::Positional, cl::desc("<program bytecode file>"),
- cl::Required);
+ BitcodeFile(cl::Positional, cl::desc("<program bitcode file>"),
+ cl::Required);
cl::opt<std::string>
ProfileDataFile(cl::Positional, cl::desc("<llvmprof.out file>"),
@@ -115,16 +115,16 @@ int main(int argc, char **argv) {
cl::ParseCommandLineOptions(argc, argv, " llvm profile dump decoder\n");
sys::PrintStackTraceOnErrorSignal();
// Read in the bytecode file...
std::string ErrorMessage;
Module *M = 0;
- if (MemoryBuffer *Buffer = MemoryBuffer::getFileOrSTDIN(BytecodeFile,
+ if (MemoryBuffer *Buffer = MemoryBuffer::getFileOrSTDIN(BitcodeFile,
&ErrorMessage)) {
M = ParseBitcodeFile(Buffer, &ErrorMessage);
delete Buffer;
}
if (M == 0) {
- std::cerr << argv[0] << ": " << BytecodeFile << ": "
+ std::cerr << argv[0] << ": " << BitcodeFile << ": "
<< ErrorMessage << "\n";
return 1;
}
@@ -115,16 +115,16 @@ int main(int argc, char **argv) {
cl::ParseCommandLineOptions(argc, argv, " llvm profile dump decoder\n");
sys::PrintStackTraceOnErrorSignal();
- // Read in the bytecode file...
+ // Read in the bitcode file...
std::string ErrorMessage;
Module *M = 0;
diff --git a/tools/llvmc/CompilerDriver.cpp b/tools/llvmc/CompilerDriver.cpp
index b170270b0c..4be9f138ae 100644
--- a/tools/llvmc/CompilerDriver.cpp
+++ b/tools/llvmc/CompilerDriver.cpp
@@ -65,9 +65,9 @@ void DumpConfigData(CompilerDriver::ConfigData* cd, const std::string& type ){
DumpAction(&cd->Linker);
}
-static bool GetBytecodeDependentLibraries(const std::string &fname,
- Module::LibraryListType& deplibs,
- std::string* ErrMsg) {
+static bool GetBitcodeDependentLibraries(const std::string &fname,
+ Module::LibraryListType& deplibs,
+ std::string* ErrMsg) {
ModuleProvider *MP = 0;
if (MemoryBuffer *Buffer = MemoryBuffer::getFileOrSTDIN(fname)) {
MP = getBitcodeModuleProvider(Buffer);
@@ -558,8 +558,8 @@ private:
}
/// This method processes a linkage item. The item could be a
/// Bytecode file needing translation to native code and that is
/// dependent on other bytecode libraries, or a native code
/// library that should just be linked into the program.
bool ProcessLinkageItem(const llvm::sys::Path& link_item,
SetVector<sys::Path>& set,
@@ -586,11 +586,11 @@ private:
// If we got here fullpath is the path to the file, and its readable.
set.insert(fullpath);
- // If its an LLVM bytecode file ...
- if (fullpath.isBytecodeFile()) {
+ // If its an LLVM bitcode file ...
+ if (fullpath.isBitcodeFile()) {
// Process the dependent libraries recursively
Module::LibraryListType modlibs;
- if (GetBytecodeDependentLibraries(fullpath.toString(),modlibs, &err)) {
+ if (GetBitcodeDependentLibraries(fullpath.toString(),modlibs, &err)) {
// Traverse the dependent libraries list
Module::lib_iterator LI = modlibs.begin();
Module::lib_iterator LE = modlibs.end();
@@ -675,7 +675,7 @@ public:
// Get the suffix of the file name
const std::string& ftype = I->second;
// If its a library, bytecode file, or object file, save
// it for linking below and short circuit the
// pre-processing/translation/assembly phases
if (ftype.empty() || ftype == "o" || ftype == "bc" || ftype=="a") {
@@ -771,7 +771,7 @@ public:
// ll -> bc Helper
if (action.isSet(OUTPUT_IS_ASM_FLAG)) {
/// The output of the translator is an LLVM Assembly program
/// We need to translate it to bytecode
Action* action = new Action();
action->program.set("llvm-as");
action->args.push_back(InFile.toString());
@@ -816,7 +816,7 @@ public:
// ll -> bc Helper
if (action.isSet(OUTPUT_IS_ASM_FLAG)) {
/// The output of the optimizer is an LLVM Assembly program
/// We need to translate it to bytecode with llvm-as
Action* action = new Action();
action->program.set("llvm-as");
action->args.push_back(InFile.toString());
@@ -558,8 +558,8 @@ private:
}
/// This method processes a linkage item. The item could be a
- /// Bytecode file needing translation to native code and that is
- /// dependent on other bytecode libraries, or a native code
+ /// Bitcode file needing translation to native code and that is
+ /// dependent on other bitcode libraries, or a native code
/// library that should just be linked into the program.
bool ProcessLinkageItem(const llvm::sys::Path& link_item,
@@ -675,7 +675,7 @@ public:
// Get the suffix of the file name
const std::string& ftype = I->second;
- // If its a library, bytecode file, or object file, save
+ // If its a library, bitcode file, or object file, save
// it for linking below and short circuit the
// pre-processing/translation/assembly phases
@@ -771,7 +771,7 @@ public:
if (action.isSet(OUTPUT_IS_ASM_FLAG)) {
/// The output of the translator is an LLVM Assembly program
- /// We need to translate it to bytecode
+ /// We need to translate it to bitcode
Action* action = new Action();
action->program.set("llvm-as");
@@ -816,7 +816,7 @@ public:
if (action.isSet(OUTPUT_IS_ASM_FLAG)) {
/// The output of the optimizer is an LLVM Assembly program
- /// We need to translate it to bytecode with llvm-as
+ /// We need to translate it to bitcode with llvm-as
Action* action = new Action();
action->program.set("llvm-as");
diff --git a/tools/opt/opt.cpp b/tools/opt/opt.cpp
index ace0d3c9bc..4eca308425 100644
--- a/tools/opt/opt.cpp
+++ b/tools/opt/opt.cpp
@@ -46,7 +46,7 @@ PassList(cl::desc("Optimizations available:"));
// Other command line options...
//
static cl::opt<std::string>
-InputFilename(cl::Positional, cl::desc("<input bytecode file>"),
+InputFilename(cl::Positional, cl::desc("<input bitcode file>"),
cl::init("-"), cl::value_desc("filename"));
static cl::opt<std::string>
@@ -61,7 +61,7 @@ PrintEachXForm("p", cl::desc("Print module after each transformation"));
static cl::opt<bool>
NoOutput("disable-output",
- cl::desc("Do not write result bytecode file"), cl::Hidden);
+ cl::desc("Do not write result bitcode file"), cl::Hidden);
static cl::opt<bool>
NoVerify("disable-verify", cl::desc("Do not verify result module"), cl::Hidden);
@@ -330,7 +330,7 @@ int main(int argc, char **argv) {
if (ErrorMessage.size())
cerr << ErrorMessage << "\n";
else
- cerr << "bytecode didn't read correctly.\n";
+ cerr << "bitcode didn't read correctly.\n";
return 1;
}
@@ -362,7 +362,7 @@ int main(int argc, char **argv) {
// If the output is set to be emitted to standard out, and standard out is a
// console, print out a warning message and refuse to do it. We don't
// impress anyone by spewing tons of binary goo to a terminal.
- if (!Force && !NoOutput && CheckBytecodeOutputToConsole(Out,!Quiet)) {
+ if (!Force && !NoOutput && CheckBitcodeOutputToConsole(Out,!Quiet)) {
NoOutput = true;
}
@@ -418,7 +418,7 @@ int main(int argc, char **argv) {
if (!NoVerify && !VerifyEach)
Passes.add(createVerifierPass());
// Write bytecode out to disk or cout as the last step...
if (!NoOutput && !AnalyzeOnly)
Passes.add(CreateBitcodeWriterPass(*Out));
@@ -418,7 +418,7 @@ int main(int argc, char **argv) {
if (!NoVerify && !VerifyEach)
Passes.add(createVerifierPass());
- // Write bytecode out to disk or cout as the last step...
+ // Write bitcode out to disk or cout as the last step...
if (!NoOutput && !AnalyzeOnly)
Passes.add(CreateBitcodeWriterPass(*Out));